from setuptools import setup, find_packages

setup(
    name='aegish',
    version='0.1.1',
    packages=find_packages(where="src"),
    package_dir={"": "src"},
    install_requires=[
        'openai',
        'google-genai',
        'anthropic',
        'ollama',
    ],
    entry_points={
        'console_scripts': [
            'ag = aegish.main:main',
        ],
    },
    author='Zain Marshall',
    description='Natural language to Linux command converter',
    include_package_data=True,
    zip_safe=False,
)



import sys

from aegish.gemini import GeminiHandler
from aegish.safetychecker import SafetyChecker
from aegish.inputhandler import InputHandler
from aegish.postprocess import PostProcessor
from aegish.commandrunner import CommandRunner
from aegish.ollama import OllamaHandler
from aegish.chatgpt import OpenAIHandler
from aegish.claude import ClaudeHandler
from aegish.config import load_config
from aegish.debug import print_debug



def main():
	# input
	args, user_prompt = InputHandler.get()

	config = load_config()
	provider = config.get('provider')
	
	# system prompt
	SYSTEM_PROMPT = "You are an expert Linux assistant. Convert the user's natural language request into a safe, correct Linux shell command. If the request is ambiguous or incomplete, infer the most helpful and complete command. For example, if the user says 'git commit', output 'git add . && git commit' to ensure all changes are included. Only output the command, and combine steps when it improves usability."
	prompt = f"{SYSTEM_PROMPT}\nUser: {user_prompt}"

	try:
		# Handle the ai providers
		handler = None
		response = None
		if(provider == 'gemini'):
			handler = GeminiHandler()
		elif(provider == 'ollama'):
			handler = OllamaHandler()
		elif(provider == 'openai'):
			handler = OpenAIHandler()
		elif(provider == 'claude'):
			handler = ClaudeHandler()
		else:
			raise ValueError(f"Unknown provider: {provider}")

		response = handler.generate(prompt)
		print_debug(f"Raw response from {provider}: {response}")

		command = PostProcessor.clean(response)

	except Exception as e:
		print(f"Provider error: {e}", file=sys.stderr)
		print(f"Have you run ag --config and saved your preferences? Aegish won't work until you have done so.")
		sys.exit(3)

	# Safety check
	if not args.no_safety and not SafetyChecker.confirm_and_run(command):
		sys.exit(0)

	# Prinot only should just only print
	if args.print_only:
		print(command)
		return

	# Run the command
	CommandRunner.run(command)



if __name__ == '__main__':
	main()




import argparse
import sys
from aegish.config import configure_interactive
from aegish.debug import print_debug, set_debug


class InputHandler:

    @staticmethod
    def get():
        parser = argparse.ArgumentParser(description="Converting natural language to linux prompts")
        parser.add_argument('text', nargs='*', help='The natural language command to convert')
       # parser.add_argument('--configure-system-prompt', default=None, help='System prompt to prepend to the user prompt')
        parser.add_argument('--print-only', action='store_true', help='Only print the generated command, do not run it')
        parser.add_argument('--no-safety', action='store_true', help='Disable safety checks on generated commands')
        parser.add_argument('--configure', action='store_true', help='Configure aegish')
        parser.add_argument('--debug', action='store_true', help='Enable debug output')
        args = parser.parse_args()

        # Enter configure mode if --configure
        if args.configure:
            configure_interactive()
            sys.exit(0)
        
        # Print debug messages if debug is selected
        set_debug(args.debug)

        # If the text is blank, with no text
        if not args.text:
            print("No input provided. Usage: ag <command>", file=sys.stderr)
            sys.exit(1)

        user_prompt = ' '.join(args.text).strip() if args.text else sys.stdin.read().strip()
        return args, user_prompt
